Struct
QmiMessageUimWriteRecordOutput
since: 1.6
Description [src]
struct QmiMessageUimWriteRecordOutput {
/* No available fields */
}
The QmiMessageUimWriteRecordOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.6
Instance methods
qmi_message_uim_write_record_output_get_card_result
Get the ‘Card Result’ field from self.
since: 1.37
qmi_message_uim_write_record_output_get_response_in_indication_token
Get the ‘Response In Indication Token’ field from self.
since: 1.37
qmi_message_uim_write_record_output_ref
Atomically increments the reference count of self by one.
since: 1.6
qmi_message_uim_write_record_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.6